ItemData class

create by 张风捷特烈 on 2023/8/18 contact me by email 1981462002@qq.com

Constructors

ItemData({required String groupName, List<String> users = const []})

Properties

groupName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

testData List<ItemData>
no setter