ListModel<E> class

Constructors

ListModel({required GlobalKey<AnimatedListState> listKey, required dynamic removedItemBuilder, required Iterable<E> initialItems})

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setter
listKey GlobalKey<AnimatedListState>
final
removedItemBuilder → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

indexOf(E item) int
insert(int index, E item) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAt(int index) → E
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) → E