ColorLabel enum

create by 张风捷特烈 on 2020/9/21 contact me by email 1981462002@qq.com

Inheritance
Available extensions

Values

blue → const ColorLabel
const ColorLabel('Blue', Colors.blue)
pink → const ColorLabel
const ColorLabel('Pink', Colors.pink)
green → const ColorLabel
const ColorLabel('Green', Colors.green)
yellow → const ColorLabel
const ColorLabel('Orange', Colors.orange)
grey → const ColorLabel
const ColorLabel('Grey', Colors.grey)

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ColorLabel>
A constant List of the values in this enum, in order of their declaration.