User class

create by 张风捷特烈 on 2020/9/21 contact me by email 1981462002@qq.com

Constructors

User(String name, bool man, String image)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
image String
final
man bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited