DisplayPlugin class
- Implemented types
Constructors
- DisplayPlugin()
-
factory
Properties
- appVersion → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
myIcon
→ List<
IconData> -
no setteroverride
- randomColor → Color
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
DisplayAbility ability) → void -
showAbout(
BuildContext context) → Future -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited